@@ -2,9 +2,8 @@
 from paste.registry import StackedObjectProxy
 from paste.wsgiwrappers import WSGIResponse as Response
 
-from pylons.controllers import Controller, RPCController
+from pylons.controllers import Controller, XMLRPCController
 from pylons.decorators import jsonify
-from pylons.legacy import m, params
 
 c = StackedObjectProxy(name="C")
 g = StackedObjectProxy(name="G")
