@@ -5,6 +5,7 @@ for Myghty, Paste errorware, and prefixing Routes if necessary.
 """
 import os
 from paste.deploy.converters import asbool
+import pylons.templating
 
 class Config(object):
     """Pylons configuration object
@@ -20,6 +21,10 @@ class Config(object):
     
     ``myghty``
         The myghty configuration dict that was used to initialize Myghty
+    ``template_options``
+        Full dict of template options that any TG compatible plugin should
+        be able to parse. Comes with basic config needed for Myghty, Kid,
+        and Mako.
     ``map``
         Mapper object used for Routing. Yes, it is possible to add routes
         after your application has started running.
@@ -54,6 +59,7 @@ class Config(object):
         if environ_config is None:
             environ_config = {}
         self.myghty = myghty
+        self.template_options = {}
         self.map = map
         self.paths = paths
         self.environ_config = environ_config
@@ -65,7 +71,7 @@ class Config(object):
         self.app_conf = {}
         self.template_engines = []
     
-    def add_template_engine(self, engine, root, options, alias=None):
+    def add_template_engine(self, engine, root, options=None, alias=None):
         """Add additional template engines for configuration on Pylons WSGI init
         
         ``engine``
@@ -75,7 +81,8 @@ class Config(object):
             Template root for the engine
         
         ``options``
-            Dict of additional options used during engine initialization
+            Dict of additional options used during engine initialization, if
+            not provided, default to using the template_options dict.
         
         ``alias``
             Name engine should respond to when actually used. This allows for
@@ -112,11 +119,13 @@ class Config(object):
             # Add old default as additional engine
             config.template_engines.append(old_default)
         """
+        if not options:
+            options = self.template_options
         config = dict(engine=engine, template_root=root, 
             template_options=options, alias=alias)
         self.template_engines.append(config)
     
-    def init_app(self, global_conf, app_conf, package):
+    def init_app(self, global_conf, app_conf, package, template_engine='pylonsmyghty'):
         """Initialize configuration for the application
         
         ``global_config``
@@ -140,6 +149,9 @@ class Config(object):
             that into account.
         ``package``
             The name of the application package, to be stored in the app_conf.
+        ``template_engine``
+            Declare the default template engine to setup. Choices are kid, genshi,
+            mako, and pylonsmyghty (the default custom Pylons plugin).
         """
         self.global_conf = global_conf
         self.app_conf = app_conf
@@ -185,12 +197,8 @@ class Config(object):
         myghty_defaults.update(self.myghty)
         
         # Merge additional globals
-        myghty_defaults.setdefault('allow_globals', [])
-                
-        myghty_defaults['allow_globals'].extend(
-            ['c', 'h', 's', '_', 'session', 'request', 'params', 'g', 'render',
-            'render_fragment']
-        )
+        myghty_defaults.setdefault('allow_globals',
+                                   []).extend(pylons.templating.PYLONS_VARS)
         
         self.myghty = myghty_defaults
         myghty_template_options = {}
@@ -214,9 +222,28 @@ class Config(object):
         if 'cache_data_dir' not in app_conf:
             app_conf['cache_data_dir'] = os.path.join(app_conf['cache_dir'], 
             'cache')
+
+        # Setup the main template options dict
+        self.template_options = opts = myghty_template_options
+
+        # Rearrange template options as default for Mako
+        opts['mako.directories'] = self.paths['templates']
+        opts['mako.filesystem_checks'] = True
+        if 'cache_dir' in app_conf:
+            opts['mako.module_directory'] = os.path.join(app_conf['cache_dir'], 
+                                                     'templates')
         
+        # Setup kid defaults
+        opts['kid.assume_encoding'] = 'utf-8'
+        opts['kid.encoding'] = 'utf-8'
+
         # Prepare our default template engine
-        self.add_template_engine('pylonsmyghty', None, myghty_template_options)
+        if template_engine == 'pylonsmyghty':
+            self.add_template_engine('pylonsmyghty', None, myghty_template_options)
+        elif template_engine == 'mako':
+            self.add_template_engine('mako', '')
+        elif template_engine in ['genshi', 'kid']:
+            self.add_template_engine(template_engine, package + '.templates')
         
         # Save our errorware values
         self.errorware = errorware
