@@ -1,48 +1,32 @@
-"""Helpers object, Paste Template config and misc. functionality.
-
-The util module provides the main Helper object used by Pylons.
+"""Paste Template and Pylons utility functions
 
 PylonsTemplate is a Paste Template sub-class that configures the source
-directory and default plug-ins for a new Pylons project.
+directory and default plug-ins for a new Pylons project. The minimal template
+provides a more minimal template with less additional directories and layout.
 """
-import os.path
-from paste.deploy.config import CONFIG
+import warnings
+
 from paste.script.templates import Template
-import pylons
 
-def log(msg):
-    """Log a message to the output log."""
-    pylons.request.environ['wsgi.errors'].write('=> %s\n'%str(msg))
+import pylons.helpers
+import pylons.i18n
 
-def _(value):
-    """Mark a string for translation
+def func_move(name, moved_to='pylons.i18n'):
+    return ("The %s function has moved to %s, please update your import "
+            "statements to reflect the move." % (name, moved_to))
+
+def deprecated(func, message):
+    def deprecated_method(*args, **kargs):        
+        warnings.warn(message, DeprecationWarning, 2)
+        return func(*args, **kargs)
+    deprecated_method.__doc__ = message + "\n\n" + func.__doc__
+    return deprecated_method
+
+get_lang = deprecated(pylons.i18n.get_lang, func_move('get_lang'))
+set_lang = deprecated(pylons.i18n.set_lang, func_move('set_lang'))
+_ = deprecated(pylons.i18n._, func_move('_'))
+log = deprecated(pylons.helpers.log, func_move('log', moved_to='pylons.helpers'))
     
-    Mark a string to be internationalized as follows:
-    
-    .. code-block:: Python
-    
-        h._('This should be in lots of languages')
-    """
-    return pylons.translator['translator'].gettext(value)
-
-def set_lang(lang):
-    """Set the language used"""
-    if lang is None:
-        pylons.translator['translator'] = _Translator()
-    else:
-        from pkg_resources import resource_exists
-        from pylons.i18n.translation import egg_translation
-        project_name = CONFIG['app_conf']['package']
-        catalog_path = os.path.join('i18n', lang, 'LC_MESSAGES')
-        if not resource_exists(project_name, catalog_path):
-            raise LanguageError('Language catalog %s not found' % \
-                                os.path.join(project_name, catalog_path))
-        pylons.translator['translator'] = \
-            egg_translation(project_name, lang=catalog_path)
-
-def get_lang():
-    return pylons.translator.get('lang')
-
 def get_prefix(environ):
     if 'paste.config' in environ:
         prefix = environ['paste.config']['app_conf'].get('prefix', '')
@@ -84,15 +68,22 @@ class AttribSafeContextObj(object):
             return object.__getattribute__(self, name)
         except AttributeError:
             return ''
-
-class LanguageError(Exception):
-    """Exception raised when a problem occurs with changing languages"""
-    pass
-
-class _Translator(object):
-    """An empty gettext translator which just returns the original string"""
-    def gettext(self, value):
-        return value
+    def __repr__(self):
+        attrs = [(name, value)
+                 for name, value in self.__dict__.items()
+                 if not name.startswith('_')]
+        attrs.sort()
+        parts = []
+        for name, value in attrs:
+            value_repr = repr(value)
+            if len(value_repr) > 70:
+                value_repr = value_repr[:60] + '...' + value_repr[-5:]
+            parts.append('%s=%s' % (name, value_repr))
+        return '<%s.%s %s %s>' % (
+            self.__class__.__module__,
+            self.__class__.__name__,
+            hex(id(self)).split('x')[1],
+            ' '.join(parts))
 
 class PylonsTemplate(Template):
     _template_dir = 'templates/default_project'
@@ -107,4 +98,4 @@ class MinimalPylonsTemplate(Template):
 
 __all__ = ['AttribSafeContextObj', 'ContextObj', 'Helpers', 'class_name_from_module_name',
     'log', '_', 'set_lang', 'get_lang']
-__pudge_all__ = __all__ + ['PylonsTemplate']
+__pudge_all__ = __all__ + ['MinimalPylonsTemplate', 'PylonsTemplate']
